@@ -20,7 +20,6 @@ from docutils.parsers import rst
 from docutils.parsers.rst.directives.tables import Table
 from docutils.statemachine import ViewList
 import pbr.version
-import six
 from sphinx.util import logging
 from sphinx.util.osutil import copyfile
 import yaml
@@ -230,7 +229,8 @@ class RestParametersDirective(Table):
                         location=(self.env.docname, None))
             return
         except yaml.YAMLError as exc:
-            LOG.exception(exc_info=exc)
+            LOG.exception(exc_info=exc,
+                          msg="Error while parsing file [%s]." % fpath)
             raise
 
         if lookup:
@@ -392,7 +392,7 @@ class RestParametersDirective(Table):
         groups = []
         trow = nodes.row()
         entry = nodes.entry()
-        para = nodes.paragraph(text=six.u(table_data))
+        para = nodes.paragraph(text=str(table_data))
         entry += para
         trow += entry
         rows.append(trow)
@@ -642,6 +642,9 @@ def copy_assets(app, exception):
     builders = ('html', 'readthedocs', 'readthedocssinglehtmllocalmedia')
     if app.builder.name not in builders or exception:
         return
+    dirtree = os.path.join(app.builder.outdir, '_static/fonts')
+    if not os.path.exists(dirtree):
+        os.makedirs(dirtree)
     LOG.info('Copying assets: %s', ', '.join(assets))
     LOG.info('Copying fonts: %s', ', '.join(fonts))
     for asset in assets:
@@ -690,4 +693,8 @@ def setup(app):
     # _static directory during final build.
     app.connect('build-finished', copy_assets)
 
-    return {'version': __version__}
+    return {
+        'parallel_read_safe': True,
+        'parallel_write_safe': True,
+        'version': __version__,
+    }
